@@ -47,13 +47,13 @@ orig_xsd_archival_agreement = SEDA1XSDExport.xsd_archival_agreement
 def xsd_archival_agreement(self, parent, transfer):
     orig_xsd_archival_agreement(self, parent, transfer)
     self.element_schema(parent, 'ArchivalProfile', 'qdt:ArchivesIDType',
-                        fixed_value=transfer.ark)
+                        fixed_value=u'ark:/' + transfer.ark)
 
 
 # override agency_id to return ark instead of eid
 @monkeypatch(SEDA1XSDExport)
 def agency_id(self, agency):
-    return agency.agency.ark
+    return None if agency.agency is None else 'ark:/' + agency.agency.ark
 
 
 SEDAArchiveTransferIClonableAdapter.__select__ &= is_in_state('published')
