@@ -32,9 +32,13 @@ from cubicweb.hooks import metadata
 from cubes.skos.hooks import ReplaceExternalUriByEntityHook
 
 
-# skip relation involved in the logging itself, or mirroring relation
-IGNORE_RELATIONS = set(('used', 'generated', 'associated_with', 'mirror_of',
-                        'primary_email'))
+# skip relations involved in the logging itself and some others that should not
+# be logged nor impact container's modification date
+IGNORE_RELATIONS = set(('used', 'generated', 'associated_with',
+                        'primary_email',
+                        'use_authorityrecord', 'related_concept_scheme', 'use_profile',
+                        'new_version_of', 'clone_of',
+                        'scheme_entity_type', 'scheme_relation_type'))
 
 
 @objectify_predicate
@@ -87,16 +91,32 @@ def qualify_relation(subj, rtype, obj):
             return []
         return [('parent', 'subject', s_adapter)]
     # from here, we can assume rtype is not a parentship relation. Notice the relation may concerns
-    # to distinct container
+    # two distinct containers
     assert s_adapter or o_adapter
     result = []
-    if s_adapter is not None:
+    # if relation concerns two containers and one of the entity is a concept,
+    # don't log action on the concept
+    if s_adapter is not None and (o_adapter is None or _log_relation(rtype, subj, obj)):
         result.append(('border', 'subject', s_adapter))
-    if o_adapter is not None:
+    if o_adapter is not None and (s_adapter is None or _log_relation(rtype, obj, subj)):
         result.append(('border', 'object', o_adapter))
     return result
 
 
+def _log_relation(rtype, entity, target):
+    """Return boolean indicating wether the relation modification should be logged.
+
+    This is called when relation's ends are in different containers, with
+    `entity` as the potentiel activity holder and `target` the other relation's
+    end.
+    """
+    # if entity is a scheme or concept, only log if the other ends is also a
+    # concept or scheme
+    if entity.cw_etype in ('Concept', 'ConceptScheme'):
+        return target.cw_etype in ('Concept', 'ConceptScheme')
+    return True
+
+
 # generic hooks to record operations if something changed in a compound tree ###
 
 class AddOrRemoveChildrenHook(hook.Hook):
