@@ -413,8 +413,8 @@ class AssignArkWebServiceTC(CubicWebTC):
 
     def test_authenticated_organization_method_not_post(self):
         with self.admin_access.cnx() as cnx:
-            org_eid = testutils.authority_with_naa(cnx).eid
-        params = {'organization': text_type(org_eid)}
+            org_ark = testutils.authority_with_naa(cnx).ark
+        params = {'organization': org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'}, **params) as req:
             result = self.app_handle_request(req, 'ark')
@@ -431,42 +431,49 @@ class AssignArkWebServiceTC(CubicWebTC):
             result = self.app_handle_request(req, 'ark')
             self.assertEqual(json.loads(result),
                              [{'error': expected_msg.format(0)}])
-        # Specified eid does not match an Organization entity.
+        # Specified ark does not match an Organization entity.
         with self.admin_access.cnx() as cnx:
-            user_eid = cnx.find('CWUser')[0][0]
-        bad_params = {'organization': text_type(user_eid)}
+            agent_ark = testutils.agent(cnx, u'bob').ark
+        bad_params = {'organization': agent_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **bad_params) as req:
             result = self.app_handle_request(req, 'ark')
             self.assertEqual(json.loads(result),
-                             [{'error': expected_msg.format(user_eid)}])
+                             [{'error': expected_msg.format(agent_ark)}])
 
     def test_authenticated_organization_has_no_naa_method_post(self):
         with self.admin_access.cnx() as cnx:
-            org_eid = cnx.create_entity(
-                'Organization', name=u'dummy', ark=u'123').eid
+            org_ark = cnx.create_entity(
+                'Organization', name=u'dummy', ark=u'123').ark
             cnx.commit()
-        bad_params = {'organization': text_type(org_eid)}
+        bad_params = {'organization': org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **bad_params) as req:
             result = self.app_handle_request(req, 'ark')
             expected_msg = 'Organization "{0}" cannot assign ARK identifiers.'
             self.assertEqual(json.loads(result),
-                             [{'error': expected_msg.format(org_eid)}])
+                             [{'error': expected_msg.format(org_ark)}])
 
     def test_ok(self):
         with self.admin_access.cnx() as cnx:
-            org_eid = testutils.authority_with_naa(cnx).eid
+            org_ark = testutils.authority_with_naa(cnx).ark
             cnx.commit()
-        params = {'organization': text_type(org_eid)}
+        params = {'organization': org_ark}
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'},
                 method='POST', **params) as req:
             result = self.app_handle_request(req, 'ark')
             self.assertEqual(json.loads(result),
                              [{'ark': '0/a000000001'}])
+        params = {'organization': 'ark://' + org_ark}
+        with self.admin_access.web_request(
+                headers={'Accept': 'application/json'},
+                method='POST', **params) as req:
+            result = self.app_handle_request(req, 'ark')
+            self.assertEqual(json.loads(result),
+                             [{'ark': '0/a000000002'}])
 
 
 class TimelineViewsTC(CubicWebTC):
