@@ -1,5 +1,5 @@
 # coding: utf-8
-# copyright 2015-2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -20,20 +20,16 @@ import json
 
 from logilab.common import flatten
 
-from cubicweb.devtools import PostgresApptestConfiguration, startpgcluster, stoppgcluster
+from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 
-from cubes.saem_ref.views.autocompletesearch import words_matching_term
+from cubicweb_saem_ref.views.autocompletesearch import words_matching_term
 
 import testutils
 
 
 def setUpModule():
-    startpgcluster(__file__)
-
-
-def tearDownModule():
-    stoppgcluster(__file__)
+    testutils.startpgcluster(__file__)
 
 
 def sql(cnx, string, param=None):
