@@ -1,4 +1,4 @@
-# copyright 2015-2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -21,7 +21,7 @@ import unittest
 
 from cubicweb import devtools  # noqa
 
-from cubes.saem_ref.site_cubicweb import print_tzdatetime_local
+from cubicweb_saem_ref.site_cubicweb import print_tzdatetime_local
 
 
 class PrintTZDatetimeTC(unittest.TestCase):
@@ -36,5 +36,6 @@ class PrintTZDatetimeTC(unittest.TestCase):
         self.assertEqual(print_tzdatetime_local(value, req),
                          '2015/05/26 16:12')
 
+
 if __name__ == '__main__':
     unittest.main()
