@@ -1,5 +1,5 @@
 # coding: utf-8
-# copyright 2015-2016 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2015 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -16,17 +16,13 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from cubicweb.devtools.testlib import CubicWebTC
-from cubicweb.devtools import PostgresApptestConfiguration, startpgcluster, stoppgcluster
+from cubicweb.devtools import PostgresApptestConfiguration
 
 import testutils
 
 
 def setUpModule():
-    startpgcluster(__file__)
-
-
-def tearDownModule():
-    stoppgcluster(__file__)
+    testutils.startpgcluster(__file__)
 
 
 class SKOSImportTC(CubicWebTC):
@@ -98,6 +94,7 @@ class LCSVImportTC(CubicWebTC):
             self.assertEqual(concept1.cwuri,
                              'ark:/0/c%09d' % concept1.eid)
 
+
 if __name__ == '__main__':
     import unittest
     unittest.main()
